MAX_DATA_ROWS = 100

MAX_DATA_CHARS = 30000

TIMEOUT_SECONDS = 30.0

MAX_RETRIES = 3

CHUNK_SIZE = 10000

DEFAULT_OPENAI_MODEL = "openai:gpt-4o"
DEFAULT_ANTHROPIC_MODEL = "anthropic:claude-3-5-sonnet-latest"
DEFAULT_GOOGLE_MODEL = "google-vertex:gemini-2.5-pro"
DEFAULT_MISTRAL_MODEL = "mistral:mistral-large-latest"
DEFAULT_COHERE_MODEL = "cohere:command-r"

MARKITDOWN_TYPES = {"pptx", "docx", "xlsx", "xls", "pdf", "html"}
TEXT_TYPES = {"md", "txt", "json", "xml", "yaml", "yml", "rtf"}
